# quickpython-mvc
`MVC` `fast` `CRUD` `ORM` `database` `chained`


```
这是一款简单的、方便的、快速的ORM框架。

PS: 让CRUD回归简单 by lo106258
```

# 开始

# 其他
```
你可以关注我更多产品：
[`quickpython`](https://github.com/quickpython)
```
